<!-- vale Microsoft.Headings = NO -->
# Security Policy

## Supported Versions

| Version                                                         | Supported |
| --------------------------------------------------------------- | --------- |
| [Latest](https://github.com/haru52/convertflac/releases/latest) | ✅        |
| Others                                                          | ❌        |

## Reporting a Vulnerability

[haru's contact form](https://docs.google.com/forms/d/e/1FAIpQLSddUF5PDhRpYPZ8VGVZClTBQCo-SQb4QzszOZanmWjUnH_stw/viewform?usp=sf_link)
